@@ -55,7 +55,7 @@ URLENCODED_CONTENT_TYPE = "application/x-www-form-urlencoded"
 #  https://developers.google.com/api-client-library/python/auth/installed-app
 OOB_REDIRECT_URI = "urn:ietf:wg:oauth:2.0:oob"
 
-DEFAULT_ISS = "https://accounts.google.com"
+DEFAULT_ISS = ("https://accounts.google.com", "accounts.google.com")
 
 ## The URL that provides public certificates for verifying ID tokens issued
 ## by Google's OAuth 2.0 authorization server.
@@ -340,6 +340,8 @@ class Oauth2Manager:
 
             response_type (str):
 
+                * Optional
+
                 * OAuth2 response type
 
                 * Defaults to Authorization Code Flow response type
@@ -441,6 +443,8 @@ class Oauth2Manager:
 
             grant_type (str):
 
+                * Optional
+
                 * OAuth2 grant type
 
                 * defaults to ``code`` (Authorization code flow)
@@ -623,7 +627,10 @@ class Oauth2Manager:
         client_creds = client_creds or self.client_creds
         request = self._build_refresh_request(user_creds, client_creds)
         json_res = await self._send_request(request)
-        return self._build_user_creds_from_res(json_res)
+        final_user_creds = self._build_user_creds_from_res(json_res)
+        if not final_user_creds.get('refresh_token'):
+            final_user_creds['refresh_token'] = user_creds.get('refresh_token')
+        return final_user_creds
 
     def _build_refresh_request(self, user_creds, client_creds):
         data = dict(
@@ -778,7 +785,9 @@ class OpenIdConnectManager(Oauth2Manager):
                 * Some OpenID scopes that you can include: ['email', 'profile', 'openid']
 
             display (str):
-            
+
+                * Optional
+
                 * An ASCII string value for specifying how the authorization server displays the authentication and consent user interface pages.
                 
                 * The following values are specified, and accepted by the Google servers, but do not have any effect on its behavior:
@@ -859,6 +868,8 @@ class OpenIdConnectManager(Oauth2Manager):
 
             openid_realm (str):
 
+                * Optional
+
                 * openid.realm is a parameter from the OpenID 2.0 protocol.
                 
                 * It is used in OpenID 2.0 requests to signify the URL-space for which an authentication request is valid.
@@ -869,6 +880,8 @@ class OpenIdConnectManager(Oauth2Manager):
 
             hd (str):
 
+                * Optional
+
                 * The hd (hosted domain) parameter streamlines the login process for G Suite hosted accounts.
                 
                 * By including the domain of the G Suite user (for example, mycollege.edu), you can indicate that the account selection UI should be optimized for accounts at that domain.
@@ -883,6 +896,8 @@ class OpenIdConnectManager(Oauth2Manager):
 
             response_type (str):
 
+                * Optional
+
                 * OAuth2 response type
 
                 * Defaults to Authorization Code Flow response type
@@ -1000,6 +1015,8 @@ class OpenIdConnectManager(Oauth2Manager):
 
             grant_type (str):
 
+                * Optional
+
                 * OAuth2 grant type
 
                 * defaults to ``code`` (Authorization code flow)
@@ -1012,12 +1029,16 @@ class OpenIdConnectManager(Oauth2Manager):
 
             hd (str):
 
+                * Optional
+
                 * hosted domain for G-suite
 
                 * used for id_token verification
 
             verify (str):
 
+                * Optional
+
                 * Whether or not to verify the received id_token
 
                 * Unless you're building a speed critical application AND you're receiving your tokens directly from Google, you should leave this as True.
@@ -1081,10 +1102,11 @@ class OpenIdConnectManager(Oauth2Manager):
             id_token = jwt.decode(id_token_jwt, certs=certs, verify=True)
         except ValueError as e:
             raise AuthError(e)
-        # Verify iss (The Issuer Identifier for the Issuer of the response) is https://accounts.google.com
-        if id_token["iss"] != DEFAULT_ISS:
+        # Verify iss (The Issuer Identifier for the Issuer of the response)
+        # Either https://accounts.google.com or accounts.google.com
+        if id_token["iss"] not in DEFAULT_ISS:
             raise AuthError(
-                f"Invalid issuer, got: {id_token['iss']}, expected: {DEFAULT_ISS}"
+                f"Invalid issuer, got: {id_token['iss']}, expected: {' or '.join(DEFAULT_ISS)}"
             )
         if nonce is not None:
             if nonce != id_token["nonce"]:
