@@ -45,9 +45,10 @@ class AiohttpSession(ClientSession, AbstractSession):
 
             # If downloading file:
             if request.media_download:
+                chunk_size = request.media_download.chunk_size
                 download_file = request.media_download.file_path
                 async with aiofiles.open(download_file, "wb+") as f:
-                    async for line in response.content:
+                    async for line in response.content.iter_chunked(chunk_size):
                         await f.write(line)
             else:
                 if response.status != 204:  # If no (no content)
